# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.machine import Machine


class TestMachine(unittest.TestCase):
    """Machine unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Machine:
        """Test Machine
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `Machine`
        """
        model = Machine()
        if include_optional:
            return Machine(
                machine_id = '',
                cpus = [
                    cybee_sdk.api.models.phy_cpu.PhyCpu(
                        vendor = '', 
                        brand = '', 
                        architecture = '', 
                        cores = [
                            cybee_sdk.api.models.cores_group.CoresGroup(
                                variant = '', 
                                cores_count = 56, 
                                threads_per_core = 56, 
                                freq = 1.337, )
                            ], )
                    ],
                os = cybee_sdk.api.models.os.Os(
                    name = '', 
                    kernel_version = '', 
                    os_version = '', 
                    long_os_version = '', 
                    distribution_id = '', 
                    host_name = '', 
                    license_info = '', 
                    domain_name = '', ),
                mass_storage = [
                    cybee_sdk.api.models.mass_storage.MassStorage(
                        storage_format = null, 
                        id = '', 
                        device_path = '', 
                        name = '', 
                        total_size = 56, 
                        largest_free_space = 56, 
                        support = null, 
                        content = [
                            cybee_sdk.api.models.partition.Partition(
                                id = '', 
                                table_index = 56, 
                                device_path = '', 
                                size = 56, 
                                offset = 56, 
                                system_required = True, )
                            ], )
                    ],
                filesystems = [
                    cybee_sdk.api.models.filesystem.Filesystem(
                        name = '', 
                        filesystem = '', 
                        mount_points = [
                            ''
                            ], 
                        total_size = 56, 
                        available_space = 56, 
                        is_root = True, )
                    ],
                ifaces = [
                    cybee_sdk.api.models.iface.Iface(
                        mac_address = '', 
                        ip_addresses = [
                            cybee_sdk.api.models.addr.Addr(
                                ip_version = 'V4', 
                                ip = '', 
                                broadcast = '', 
                                netmask = '', )
                            ], 
                        name = '', )
                    ],
                dns = [
                    cybee_sdk.api.models.dns.Dns(
                        hostname = '', )
                    ],
                ntp = cybee_sdk.api.models.ntp.Ntp(
                    globaly_synchronized = null, ),
                memory = cybee_sdk.api.models.memory.Memory(
                    total_memory = 56, 
                    total_swap = 56, ),
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                changed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return Machine(
                machine_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                changed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testMachine(self):
        """Test Machine"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.restore_plan_run import RestorePlanRun


class TestRestorePlanRun(unittest.TestCase):
    """RestorePlanRun unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RestorePlanRun:
        """Test RestorePlanRun
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `RestorePlanRun`
        """
        model = RestorePlanRun()
        if include_optional:
            return RestorePlanRun(
                id = '',
                task_id = '',
                snapshot_id = '',
                agent_id = '',
                programmed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                repository_id = '',
                started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                plan_config = '',
                plan_id = '',
                plan_type = '',
                status = 'finished',
                restore_summary = cybee_sdk.api.models.restore_summary.RestoreSummary(
                    id = '', 
                    seconds_elapsed = 0.0, 
                    total_files = 0.0, 
                    files_restored = 0.0, 
                    files_skipped = 0.0, 
                    total_bytes = 0.0, 
                    bytes_restored = 0.0, 
                    bytes_skipped = 0.0, ),
                errors = [
                    ''
                    ]
            )
        else:
            return RestorePlanRun(
                id = '',
                agent_id = '',
                repository_id = '',
                started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                plan_id = '',
                plan_type = '',
        )
        """

    def testRestorePlanRun(self):
        """Test RestorePlanRun"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from uuid import UUID
from cybee_sdk.api.models.image_backup_plan_extension import ImageBackupPlanExtension
from cybee_sdk.api.models.pre_post_run_script import PrePostRunScript
from cybee_sdk.api.models.restic_backup_input import ResticBackupInput
from cybee_sdk.api.models.retention_settings import RetentionSettings
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python


class ImageBackupPlanUpdate(BaseModel):
    """
    ImageBackupPlanUpdate
    """  # noqa: E501

    name: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None
    description: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None
    repo_id: Optional[UUID] = None
    config: Optional[ResticBackupInput] = None
    schedule_enabled: Optional[StrictBool] = None
    extension: Optional[ImageBackupPlanExtension] = None
    retention_settings: Optional[RetentionSettings] = None
    pre_script: Optional[PrePostRunScript] = None
    post_script: Optional[PrePostRunScript] = None
    __properties: ClassVar[List[str]] = [
        "name",
        "description",
        "repo_id",
        "config",
        "schedule_enabled",
        "extension",
        "retention_settings",
        "pre_script",
        "post_script",
    ]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ImageBackupPlanUpdate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of config
        if self.config:
            _dict["config"] = self.config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of extension
        if self.extension:
            _dict["extension"] = self.extension.to_dict()
        # override the default output from pydantic by calling `to_dict()` of retention_settings
        if self.retention_settings:
            _dict["retention_settings"] = self.retention_settings.to_dict()
        # override the default output from pydantic by calling `to_dict()` of pre_script
        if self.pre_script:
            _dict["pre_script"] = self.pre_script.to_dict()
        # override the default output from pydantic by calling `to_dict()` of post_script
        if self.post_script:
            _dict["post_script"] = self.post_script.to_dict()
        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict["name"] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict["description"] = None

        # set to None if repo_id (nullable) is None
        # and model_fields_set contains the field
        if self.repo_id is None and "repo_id" in self.model_fields_set:
            _dict["repo_id"] = None

        # set to None if config (nullable) is None
        # and model_fields_set contains the field
        if self.config is None and "config" in self.model_fields_set:
            _dict["config"] = None

        # set to None if schedule_enabled (nullable) is None
        # and model_fields_set contains the field
        if self.schedule_enabled is None and "schedule_enabled" in self.model_fields_set:
            _dict["schedule_enabled"] = None

        # set to None if extension (nullable) is None
        # and model_fields_set contains the field
        if self.extension is None and "extension" in self.model_fields_set:
            _dict["extension"] = None

        # set to None if retention_settings (nullable) is None
        # and model_fields_set contains the field
        if self.retention_settings is None and "retention_settings" in self.model_fields_set:
            _dict["retention_settings"] = None

        # set to None if pre_script (nullable) is None
        # and model_fields_set contains the field
        if self.pre_script is None and "pre_script" in self.model_fields_set:
            _dict["pre_script"] = None

        # set to None if post_script (nullable) is None
        # and model_fields_set contains the field
        if self.post_script is None and "post_script" in self.model_fields_set:
            _dict["post_script"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ImageBackupPlanUpdate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "name": obj.get("name"),
                "description": obj.get("description"),
                "repo_id": obj.get("repo_id"),
                "config": ResticBackupInput.from_dict(obj["config"]) if obj.get("config") is not None else None,
                "schedule_enabled": obj.get("schedule_enabled"),
                "extension": ImageBackupPlanExtension.from_dict(obj["extension"])
                if obj.get("extension") is not None
                else None,
                "retention_settings": RetentionSettings.from_dict(obj["retention_settings"])
                if obj.get("retention_settings") is not None
                else None,
                "pre_script": PrePostRunScript.from_dict(obj["pre_script"])
                if obj.get("pre_script") is not None
                else None,
                "post_script": PrePostRunScript.from_dict(obj["post_script"])
                if obj.get("post_script") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.page_image_restore_plan import PageImageRestorePlan


class TestPageImageRestorePlan(unittest.TestCase):
    """PageImageRestorePlan unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PageImageRestorePlan:
        """Test PageImageRestorePlan
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `PageImageRestorePlan`
        """
        model = PageImageRestorePlan()
        if include_optional:
            return PageImageRestorePlan(
                page = 56,
                per_page = 56,
                total_items = 56,
                total_pages = 56,
                items = [
                    cybee_sdk.api.models.image_restore_plan.ImageRestorePlan(
                        id = '', 
                        name = '', 
                        description = '', 
                        repo_id = '', 
                        config = cybee_sdk.api.models.restic_restore.ResticRestore(
                            global_options = cybee_sdk.api.models.global_restic_options.GlobalResticOptions(
                                cache_dir = '', 
                                limit_download = 0.0, 
                                limit_upload = 0.0, ), 
                            exclude = [
                                ''
                                ], 
                            include = [
                                ''
                                ], 
                            iexclude = [
                                ''
                                ], 
                            iinclude = [
                                ''
                                ], 
                            host = '', 
                            path = '', 
                            tag = [
                                ''
                                ], 
                            sparse = True, 
                            target = '', 
                            verify = True, 
                            snapshot_id = '', ), 
                        schedule_enabled = True, 
                        schedule_configs = [
                            ''
                            ], 
                        last_executed = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        timestamps = cybee_sdk.api.models.time_stamps.TimeStamps(
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        affected_agents = [
                            ''
                            ], 
                        extension = cybee_sdk.api.models.image_restore_plan_extension.ImageRestorePlanExtension(
                            partitions = {
                                'key' : [
                                    56
                                    ]
                                }, ), 
                        pre_script = null, 
                        post_script = null, )
                    ]
            )
        else:
            return PageImageRestorePlan(
                page = 56,
                per_page = 56,
                total_items = 56,
                items = [
                    cybee_sdk.api.models.image_restore_plan.ImageRestorePlan(
                        id = '', 
                        name = '', 
                        description = '', 
                        repo_id = '', 
                        config = cybee_sdk.api.models.restic_restore.ResticRestore(
                            global_options = cybee_sdk.api.models.global_restic_options.GlobalResticOptions(
                                cache_dir = '', 
                                limit_download = 0.0, 
                                limit_upload = 0.0, ), 
                            exclude = [
                                ''
                                ], 
                            include = [
                                ''
                                ], 
                            iexclude = [
                                ''
                                ], 
                            iinclude = [
                                ''
                                ], 
                            host = '', 
                            path = '', 
                            tag = [
                                ''
                                ], 
                            sparse = True, 
                            target = '', 
                            verify = True, 
                            snapshot_id = '', ), 
                        schedule_enabled = True, 
                        schedule_configs = [
                            ''
                            ], 
                        last_executed = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        timestamps = cybee_sdk.api.models.time_stamps.TimeStamps(
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        affected_agents = [
                            ''
                            ], 
                        extension = cybee_sdk.api.models.image_restore_plan_extension.ImageRestorePlanExtension(
                            partitions = {
                                'key' : [
                                    56
                                    ]
                                }, ), 
                        pre_script = null, 
                        post_script = null, )
                    ],
        )
        """

    def testPageImageRestorePlan(self):
        """Test PageImageRestorePlan"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.backup_notification_filter_input import BackupNotificationFilterInput


class TestBackupNotificationFilterInput(unittest.TestCase):
    """BackupNotificationFilterInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BackupNotificationFilterInput:
        """Test BackupNotificationFilterInput
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `BackupNotificationFilterInput`
        """
        model = BackupNotificationFilterInput()
        if include_optional:
            return BackupNotificationFilterInput(
                template_id = '',
                success = cybee_sdk.api.models.common_notify_filter.CommonNotifyFilter(
                    template_id = '', 
                    filter = [
                        '0'
                        ], ),
                failed = cybee_sdk.api.models.common_notify_filter.CommonNotifyFilter(
                    template_id = '', 
                    filter = [
                        '0'
                        ], ),
                finished = cybee_sdk.api.models.common_notify_filter.CommonNotifyFilter(
                    template_id = '', 
                    filter = [
                        '0'
                        ], )
            )
        else:
            return BackupNotificationFilterInput(
        )
        """

    def testBackupNotificationFilterInput(self):
        """Test BackupNotificationFilterInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictFloat, StrictInt
from typing import Any, ClassVar, Dict, List, Optional, Union
from uuid import UUID
from cybee_sdk.api.models.restic_stats_mode_enum import ResticStatsModeEnum
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python


class RepositoryStats(BaseModel):
    """
    RepositoryStats
    """  # noqa: E501

    timestamp: datetime
    mode: ResticStatsModeEnum
    repository_id: UUID
    total_size: StrictInt
    snapshots_count: StrictInt
    total_file_count: Optional[StrictInt] = None
    total_blob_count: Optional[StrictInt] = None
    total_uncompressed_size: Optional[StrictInt] = None
    compression_ratio: Optional[Union[StrictFloat, StrictInt]] = None
    compression_progress: Optional[Union[StrictFloat, StrictInt]] = None
    compression_space_saving: Optional[Union[StrictFloat, StrictInt]] = None
    __properties: ClassVar[List[str]] = [
        "timestamp",
        "mode",
        "repository_id",
        "total_size",
        "snapshots_count",
        "total_file_count",
        "total_blob_count",
        "total_uncompressed_size",
        "compression_ratio",
        "compression_progress",
        "compression_space_saving",
    ]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RepositoryStats from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if total_file_count (nullable) is None
        # and model_fields_set contains the field
        if self.total_file_count is None and "total_file_count" in self.model_fields_set:
            _dict["total_file_count"] = None

        # set to None if total_blob_count (nullable) is None
        # and model_fields_set contains the field
        if self.total_blob_count is None and "total_blob_count" in self.model_fields_set:
            _dict["total_blob_count"] = None

        # set to None if total_uncompressed_size (nullable) is None
        # and model_fields_set contains the field
        if self.total_uncompressed_size is None and "total_uncompressed_size" in self.model_fields_set:
            _dict["total_uncompressed_size"] = None

        # set to None if compression_ratio (nullable) is None
        # and model_fields_set contains the field
        if self.compression_ratio is None and "compression_ratio" in self.model_fields_set:
            _dict["compression_ratio"] = None

        # set to None if compression_progress (nullable) is None
        # and model_fields_set contains the field
        if self.compression_progress is None and "compression_progress" in self.model_fields_set:
            _dict["compression_progress"] = None

        # set to None if compression_space_saving (nullable) is None
        # and model_fields_set contains the field
        if self.compression_space_saving is None and "compression_space_saving" in self.model_fields_set:
            _dict["compression_space_saving"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RepositoryStats from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "timestamp": obj.get("timestamp"),
                "mode": obj.get("mode"),
                "repository_id": obj.get("repository_id"),
                "total_size": obj.get("total_size"),
                "snapshots_count": obj.get("snapshots_count"),
                "total_file_count": obj.get("total_file_count"),
                "total_blob_count": obj.get("total_blob_count"),
                "total_uncompressed_size": obj.get("total_uncompressed_size"),
                "compression_ratio": obj.get("compression_ratio"),
                "compression_progress": obj.get("compression_progress"),
                "compression_space_saving": obj.get("compression_space_saving"),
            }
        )
        return _obj
